function [sys] = import_ideasResponseFunc_dataset58(fileName)
% Import Response Function Data calculated by I-DEAS Finite Element Analysis
% Dataset 58 Universal File Format (UFF) or UNV file
% 2005-07-21
% D. Coyne
% Using an extension of the UFF Read m-file, readuff.m
% N.B.: The default export Simulation universal file does not include
% response function data. One must go into the Response analysis mode
% within I-DEAS ver 9 and then select export, functions as dataset 58

[UffDataSets,Info,errmsg] = readuff(fileName);

if Info.nErrors ~= 0
    for ii=1:Info.nErrors
        disp(Info.errorMsgs{ii});
    end
end

% echo header information
iHeader=find(Info.dsTypes==151);
UffDataSets{iHeader}

% echo units information
iUnits=find(Info.dsTypes==164);
UffDataSets{iUnits}

% response analysis information
iResponseAnalysis=find(Info.dsTypes==58);
UffDataSets{iResponseAnalysis}

% generally the frequency (abscissa) vector is the same for
% the response functions, though this is not essential
% here it is assumed that the frequency vector is the same
% so that an FRD array function can be formed
nRespFuncs = length(iResponseAnalysis);
nRespPts = length(UffDataSets{iResponseAnalysis(1)}.x);
freq = zeros(nRespFuncs,nRespPts);
TF = freq;
for ii=1:nRespFuncs
    freq(ii,:) = UffDataSets{iResponseAnalysis(ii)}.x';
    TF(ii,:) = UffDataSets{iResponseAnalysis(ii)}.measData';
end
% TF(response node,freq)
sysSimpleBeam=frd(TF(1,:),freq(1,:)','Units','Hz');

for jact=1:1 % actuator
    sys=frd(TF',freq(1,:),'Units','Hz');
        figure;
        bode(sys(1,1,1),'r',sys(1,1,2),'b',sys(1,1,3),'g');
        sysaxes=findall(gcf,'XScale','log');
        set(sysaxes,'XScale','linear');
        title(['Simple Beam, Tip Actuation']);
        legend('node 2','node 5','node 8');
        hfig = findall(gcf,'type','line','visible','on');
        set(hfig,'linewidth',2.0);
        orient landscape;
%        print('-dpsc2','-append', printFile)
%        close;
end

